Elliptic curves on binary fields work.
[u/mdw/catacomb] / ec.h
diff --git a/ec.h b/ec.h
index 476d898..bb5e201 100644 (file)
--- a/ec.h
+++ b/ec.h
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
 /* -*-c-*-
  *
- * $Id: ec.h,v 1.4.4.2 2004/03/20 00:13:31 mdw Exp $
+ * $Id: ec.h,v 1.4.4.3 2004/03/21 22:39:46 mdw Exp $
  *
  * Elliptic curve definitions
  *
  *
  * Elliptic curve definitions
  *
@@ -30,6 +30,9 @@
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: ec.h,v $
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: ec.h,v $
+ * Revision 1.4.4.3  2004/03/21 22:39:46  mdw
+ * Elliptic curves on binary fields work.
+ *
  * Revision 1.4.4.2  2004/03/20 00:13:31  mdw
  * Projective coordinates for prime curves
  *
  * Revision 1.4.4.2  2004/03/20 00:13:31  mdw
  * Projective coordinates for prime curves
  *
@@ -419,18 +422,20 @@ extern void ec_destroycurve(ec_curve */*c*/);
 extern ec_curve *ec_prime(field */*f*/, mp */*a*/, mp */*b*/);
 extern ec_curve *ec_primeproj(field */*f*/, mp */*a*/, mp */*b*/);
 
 extern ec_curve *ec_prime(field */*f*/, mp */*a*/, mp */*b*/);
 extern ec_curve *ec_primeproj(field */*f*/, mp */*a*/, mp */*b*/);
 
-/* --- @ec_bin@ --- *
+/* --- @ec_bin@, @ec_binproj@ --- *
  *
  * Arguments:  @field *f@ = the underlying field for this elliptic curve
  *             @mp *a, *b@ = the coefficients for this curve
  *
  * Returns:    A pointer to the curve.
  *
  *
  * Arguments:  @field *f@ = the underlying field for this elliptic curve
  *             @mp *a, *b@ = the coefficients for this curve
  *
  * Returns:    A pointer to the curve.
  *
* Use:                Creates a curve structure for a non-supersingular elliptic
*             curve defined over a binary field.
  */
 
 extern ec_curve *ec_bin(field */*f*/, mp */*a*/, mp */*b*/);
  */
 
 extern ec_curve *ec_bin(field */*f*/, mp */*a*/, mp */*b*/);
+extern ec_curve *ec_binproj(field */*f*/, mp */*a*/, mp */*b*/);
 
 /*----- That's all, folks -------------------------------------------------*/
 
@@ -419,18 +422,20 @@ extern void ec_destroycurve(ec_curve */*c*/);
  * Returns:    A pointer to the curve.
  *
- * Use:                Creates a curve structure for a non-supersingular elliptic
- *             curve defined over a binary field.
+ * Use:                Creates a curve structure for an elliptic curve defined over
+ *             a binary field.  The @binproj@ variant uses projective
+ *             coordinates, which can be a win.
  */
 
 
 /*----- That's all, folks -------------------------------------------------*/